[![license](https://img.shields.io/badge/license-MIT-brightgreen)](https://spdx.org/licenses/MIT.html)
[![pipelines](https://gitlab.com/jlecomte/python/imxdparser/badges/master/pipeline.svg)](https://gitlab.com/jlecomte/python/imxdparser/pipelines)
[![coverage](https://gitlab.com/jlecomte/python/imxdparser/badges/master/coverage.svg)](https://jlecomte.gitlab.io/python/imxdparser/coverage/index.html)

# Intermixed Argparser

Intermixed argparser, aka imxdparser, is an argument parser that allows the unordered full mix of optional and positional arguments.

## Installation from PyPI

You can install the latest version from PyPI package repository.

~~~bash
python3 -mpip install -U imxdparser
~~~

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Locations

  * GitLab: [https://gitlab.com/jlecomte/python/imxdparser](https://gitlab.com/jlecomte/python/imxdparser)
  * PyPi: [https://pypi.org/project/imxdparser](https://pypi.org/project/imxdparser)
